export const createFragment = ({ children }) => children

export const createElement = <Props extends Record<string, unknown>>
(type: string | ((props: Props) => HTMLElement), props: Props, ...children: HTMLElement[]) => {

  if (typeof type === 'function') {
    return type({ ...props, children });
  }

  const element = document.createElement(type);

  for (const key in props) {
    const value = props[key];

    if (key === 'style') {
      for (const styleKey in value) {
        element.style[styleKey] = value[styleKey];
      }
    } else {
      element[key] = value;
    }
  }

  const flatChilds = children.reduce((acc, child) => {
    if (Array.isArray(child)) {
      acc.push(...child);
    } else {
      acc.push(child);
    }

    return acc;
  }, [] as HTMLElement[]);

  element.append(...flatChilds);

  return element
}
